@@ -21,37 +21,38 @@ except InvalidGitRepositoryError:
 debug = ndebug.create(__name__)
 
 
-def check_repo():
-    if not repo:
-        raise GitError("Not in a valid git repository")
+def check_repo(func):
+    """Decorator which checks that we are in a git repository."""
+    def function_wrapper(*args, **kwargs):
+        if repo is None:
+            raise GitError("Not in a valid git repository")
+        return func(*args, **kwargs)
+    return function_wrapper
 
 
+@check_repo
 def get_commit_log(from_rev=None):
-    """
-    Yields all commit messages from last to first.
-    """
-
-    check_repo()
+    """Yield all commit messages from last to first."""
     rev = None
     if from_rev:
         try:
             repo.commit(from_rev)
             rev = '...{from_rev}'.format(from_rev=from_rev)
         except BadName:
-            debug('Reference {} does not exist, considering all log'.format(from_rev))
+            debug('Reference {} does not exist, considering entire history'.format(from_rev))
+
     for commit in repo.iter_commits(rev):
         yield (commit.hexsha, commit.message)
 
 
+@check_repo
 def get_last_version(skip_tags=None) -> Optional[str]:
     """
-    Return last version from repo tags.
+    Find the latest version using repo tags.
 
-    :return: A string contains version number.
+    :return: A string containing a version number.
     """
-
     debug('get_last_version skip_tags=', skip_tags)
-    check_repo()
     skip_tags = skip_tags or []
 
     def version_finder(tag):
@@ -60,70 +61,72 @@ def get_last_version(skip_tags=None) -> Optional[str]:
         return tag.commit.committed_date
 
     for i in sorted(repo.tags, reverse=True, key=version_finder):
-        if re.match(r'v\d+\.\d+\.\d+', i.name):
+        if re.match(r'v\d+\.\d+\.\d+', i.name):  # Matches vX.X.X
             if i.name in skip_tags:
                 continue
-            return i.name[1:]
+            return i.name[1:]  # Strip off 'v'
+
     return None
 
 
+@check_repo
 def get_version_from_tag(tag_name: str) -> Optional[str]:
-    """Get git hash from tag
+    """
+    Get the git commit hash corresponding to a tag name.
 
     :param tag_name: Name of the git tag (i.e. 'v1.0.0')
     :return: sha1 hash of the commit
     """
-
     debug('get_version_from_tag({})'.format(tag_name))
-    check_repo()
+
     for i in repo.tags:
         if i.name == tag_name:
             return i.commit.hexsha
     return None
 
 
+@check_repo
 def get_repository_owner_and_name() -> Tuple[str, str]:
     """
-    Checks the origin remote to get the owner and name of the remote repository.
+    Check the 'origin' remote to get the owner and name of the remote repository.
 
     :return: A tuple of the owner and name.
     """
-
-    check_repo()
     url = repo.remote('origin').url
     split_url = urlsplit(url)
-    path = split_url.path
-    parts = re.search(r'[:/]([^:]+)/([^/]*?)(.git)?$', path)
+    # Select the owner and name as regex groups
+    parts = re.search(r'[:/]([^:]+)/([^/]*?)(.git)?$', split_url.path)
     if not parts:
         raise HvcsRepoParseError
+
     debug('get_repository_owner_and_name', parts)
     return parts.group(1), parts.group(2)
 
 
+@check_repo
 def get_current_head_hash() -> str:
     """
-    Gets the commit hash of the current HEAD.
+    Get the commit hash of the current HEAD.
 
-    :return: A string with the commit hash.
+    :return: The commit hash.
     """
-
-    check_repo()
     return repo.head.commit.name_rev.split(' ')[0]
 
 
+@check_repo
 def commit_new_version(version: str):
     """
-    Commits the file containing the version number variable with the version number as the commit
-    message.
+    Commit the file containing the version number variable.
 
-    :param version: The version number to be used in the commit message.
+    The commit message will be generated from the configured template.
+
+    :param version: Version number to be used in the commit message.
     """
-
-    check_repo()
     commit_subject = config.get('semantic_release', 'commit_subject')
-    commit_message = config.get('semantic_release', 'commit_message')
-
     message = commit_subject.format(version=version)
+
+    # Add an extended message if one is configured
+    commit_message = config.get('semantic_release', 'commit_message')
     if commit_message:
         message += "\n\n"
         message += commit_message.format(version=version)
@@ -139,17 +142,17 @@ def commit_new_version(version: str):
     return repo.git.commit(m=message, author=commit_author)
 
 
+@check_repo
 def tag_new_version(version: str):
     """
-    Creates a new tag with the version number prefixed with v.
+    Create a new tag with the version number, prefixed with v.
 
     :param version: The version number used in the tag as a string.
     """
-
-    check_repo()
     return repo.git.tag('-a', 'v{0}'.format(version), m='v{0}'.format(version))
 
 
+@check_repo
 def push_new_version(
     auth_token: str = None,
     owner: str = None,
@@ -158,7 +161,7 @@ def push_new_version(
     domain: str = 'github.com',
 ):
     """
-    Runs git push and git push --tags.
+    Run git push and git push --tags.
 
     :param auth_token: Authentication token used to push.
     :param owner: Organisation or user that owns the repository.
@@ -167,8 +170,6 @@ def push_new_version(
     :param server_url: Name of the server. Will be used to identify a gitlab instance.
     :raises GitError: if GitCommandError is raised
     """
-
-    check_repo()
     server = 'origin'
     if auth_token:
         token = auth_token
@@ -201,12 +202,11 @@ def push_new_version(
         raise GitError(message)
 
 
+@check_repo
 def checkout(branch: str):
     """
-    Checks out the given branch in the local repository.
+    Check out the given branch in the local repository.
 
     :param branch: The branch to checkout.
     """
-
-    check_repo()
     return repo.git.checkout(branch)
